@@ -1,6 +1,5 @@
 # *
-# *	Copyright (c) 2000 Alberto Reggiori / <alberto.reggiori@jrc.it>
-# *	ISIS/RIT, Joint Research Center Ispra (I)
+# *	Copyright (c) 2000 Alberto Reggiori <areggiori@webweaving.org>
 # *
 # * NOTICE
 # *
@@ -8,12 +7,20 @@
 # * file you should have received together with this source code. If you did not get a
 # * a copy of such a license agreement you can pick up one at:
 # *
-# *     http://xml.jrc.it/RDFStore/LICENSE
+# *     http://rdfstore.jrc.it/LICENSE
 # *
+# * Changes:
+# *     version 0.1 - 2000/11/03 at 04:30 CEST
+# *     version 0.4
+# *             - fixed a few warnings
 # *
 package RDFStore::Stanford::Digest::Generic;
 {
+use vars qw ($VERSION);
 use strict;
+ 
+$VERSION = '0.4';
+
 use RDFStore::Stanford::Digest::Abstract;
 
 @RDFStore::Stanford::Digest::Generic::ISA = qw (RDFStore::Stanford::Digest::Abstract);
@@ -49,4 +56,4 @@ Digest(3)
 
 =head1 AUTHOR
 
-	Alberto Reggiori <alberto.reggiori@jrc.it>
+	Alberto Reggiori <areggiori@webweaving.org>
