@@ -61,15 +61,11 @@ use RDFStore;
 
 my $Usage =<<EOU;
 Usage is:
-    $0 [-h] [-input_dir <valid_directoryname>] -storename <IDENTIFIER> -query <querystring> [-style <BerkeleyDB|DB_File|DBMS>] [-split <number>] [-dbms_host <hostname>] [-dbms_port <port>]
+    $0 [-h] [-input_dir <valid_directoryname>] -storename <IDENTIFIER> -query <querystring> [-compression] [-freetext] [-style <BerkeleyDB|DB_File|DBMS>] [-split <number>] [-dbms_host <hostname>] [-dbms_port <port>]
 
 Query an existing RDFStore database.
 
 -h	Print this message
--v	Be verbose
-
-[-input_dir <valid_directoryname>]
-		Input directory of existing DB files. Default is cwd.
 
 -storename <IDENTIFIER>
 		A label or identifier to identify the RDFStore database
@@ -78,12 +74,12 @@ Query an existing RDFStore database.
 		A query string to match against the RDFStore database as following:
 
 		# A && (B || C) or A && B || C
-		exp		::= 'S=' ['"'] subject ['"'] [',' 'P=' ['"'] predicate ['"']] [',' 'O=' ['"'] object ['"']] |
-				    ['('] exp [operator exp] [')']
-		operator	::= '&&' | '||' | '!'
+		exp		::= subject [',' predicate ] [',' object ] | ['('] exp [operator exp] [')'] | word
+		operator	::= 'AND' | 'OR' | 'NOT'
 		subject 	::= URI-reference | vocterm
 		predicate 	::= URI-reference | vocterm
-		object		::= URI-reference | vocterm | '"' string '"'
+		object		::= URI-reference | vocterm | word
+		word		::= '"' string '"'
 		vocterm 	::= vocprefix '::' vocprop
 		vocprefix 	::= 'RDF' | 'RDFS' | 'DC' | 'DAML'
 		vocprop 	::= string, interpreted based on 
@@ -92,8 +88,18 @@ Query an existing RDFStore database.
 		string		::= (any XML text, with "<", ">", and "&" escaped)
 
 		E.g.
-			./rdfquery -query 'S="http://www.daml.org/2000/10/daml-ont#",undef,undef && undef,undef,O=RDFStore::Stanford::Description'
+			./rdfquery -query 'http://www.daml.org/2000/10/daml-ont#,, AND ,,RDF::subject'
 
+[-input_dir <valid_directoryname>]
+		Input directory of existing DB files. Default is cwd.
+
+[-v]	Be verbose
+
+[-compression]
+                Use RLE encoding in the persistent RDFStore model
+
+[-freetext]
+                Use free-text searching
 
 [-style <BerkeleyDB|DB_File|DBMS>]
 		BerkeleyDB, DB_File or DBMS store. Default is DB_File.
@@ -114,7 +120,7 @@ print $Usage and exit if ($#ARGV<0);
 
 my $factory = new RDFStore::NodeFactory();
 
-my ($verbose,$query,$storename,$style,$split,$input_dir,$dbms_host,$dbms_port);
+my ($verbose,$compression,$freetext,$query,$storename,$style,$split,$input_dir,$dbms_host,$dbms_port);
 my @query;
 while (defined($ARGV[0]) and $ARGV[0] =~ /^[-+]/) {
     my $opt = shift;
@@ -128,27 +134,41 @@ while (defined($ARGV[0]) and $ARGV[0] =~ /^[-+]/) {
                         ($storename =~ /\/$/) );
     } elsif ($opt eq '-style') {
 	$style=shift;
+    } elsif ($opt eq '-compression') {
+        $compression = 1;
+    } elsif ($opt eq '-freetext') {
+        $freetext = 1;
     } elsif ($opt eq '-query') {
 	$query=shift;
 	# substitute using matching strings
-	$query =~ s/("[^"]*")/\$factory-\>createLiteral\($1\)/;
-	$query =~ s/((\w+:[\/]{1,3})?\w+[^,]+)/\$factory-\>createResource\(\"$1"\)/g;
-	$query =~ s/(\w+::[^\,\)]+)/\$$1/g;
-#print STDERR "1)QUERY string is = $query\n";
-	my @operators;
-	$query = join(')->intersect(',split('&&',$query))
-		if($query =~ /\&\&/);
-	if($query =~ /\|\|/) {
-		$query = join(')->unite(',split('||',$query));
+	unless($query=~/^(\w+)$/) {
+		$query =~ s/("[^"]*")/\$factory-\>createLiteral\($1\)/;
+		$query =~ s/((\w+:[\/]{1,3})?\w+[^,\s]+)/\$factory\-\>createResource\(\"$1\"\)/g;
+		$query =~ s/(\w+::[^\,\)]+)/\$$1/g;
+
+		$query =~ s#\$\$factory\-\>createResource\(\"factory\-\>createLiteral\(\"([^"]+)\"\)"\)#\$factory\-\>createLiteral\(\"$1\"\)#g;
+
+		my @operators;
+		#$query =~ s/(.+)\s+\$factory\-\>createResource\(\"AND\"\)\s+(.+)/\( $1 \)\-\>intersect\( \$model\-\>find\( $2 \) /g;
+		$query =~ s/(.+)\s+\$factory\-\>createResource\(\"AND\"\)\s+(.+)/\( $1 \)\-\>find\( $2 /g;
+		$query =~ s/(.+)\s+\$factory\-\>createResource\(\"OR\"\)\s+(.+)/\( $1 \)\-\>unite\( \$model\-\>find\( $2 \) /g;
+		$query =~ s/(.+)\s+\$factory\-\>createResource\(\"NOT\"\)\s+(.+)/\( $1 \)\-\>subtract\( \$model\-\>find\( $2 \) /g;
+	} else {
+		$query = 'undef,undef,undef,"'.$1.'"';
 	};
-	if($query =~ /\!/) {
-		$query = join(')->subtract(',split('!',$query));
-	};
-	$query .= ')';
-	$query =~ s/(intersect|unite|subtract)\(([^,]+,[^,]+,[^,]+)\)/$1\(\$model-\>find\($2\)\)/g;
+
+	$query = '$model->find'.
+			(($query=~/^\(/) ? '' : '(' ).	
+				$query.')';
+				#(($query=~/\)$/) ? '' : ')' );
+
+	$query =~ s/\,\,/\,undef\,/g;
+	$query =~ s/\s\,/ undef\,/g;
+	$query =~ s/\,\s\)/\,undef \)/g;
+	#$query =~ s/\(\s*\,/\(undef\,/g;
+	#$query =~ s/\,\s*\)/\,undef\)/g;
+	#$query =~ s/\(\s*\(/\(\$model-\>find\(/g;
 
-	$query = '$model->find('.$query
-		unless($query =~ /^\$model/);
 print STDERR "QUERY string is = $query\n\n";
 
     } elsif ($opt eq '-h') {
@@ -185,6 +205,8 @@ my $model = new RDFStore::SetModel(
 					Host =>    $dbms_host,
                                         Port =>    $dbms_port,
                                         Split       =>      $split,
+					Compression => $compression,
+					FreeText => $freetext,
 					Mode	=>	'r' ) or
 	croak "Oh dear, can not tie my model :( $!";
 my $result_model = eval $query;
@@ -193,12 +215,12 @@ my $err = $@;
 croak $err
 	if $err;
 
-my @results = $result_model->elements;
+my($results) = $result_model->elements;
 die "No results\n"
 	unless(	(defined $result_model) && 
-		($#results>=0) );
+		($#{$results}>=0) );
 
-#foreach( @{$result_model->elements} ) {
-foreach( @results ) {
-	print $_->toString."\n";
+for my $ii ( 0..$#{$results} ) {
+	my $st = $results->[$ii];
+	print $st->toString."\n";
 };
